# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the "Software"), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

import json
import time
import boto3
import os
 
ssm_client = boto3.client('ssm',region_name=os.environ['AWS_REGION'])
 
def lambda_handler(event, context):
    print("Event in Check status:%s" %event)
    input = json.loads(event['body'])
    command_id = input['command_id']
    instance_id = input['instance_id']
    print(command_id, instance_id)
   
    command_invocation_result = ssm_client.get_command_invocation(
        CommandId=command_id,
        InstanceId=instance_id,
    )
    print(command_invocation_result)
   
    status = command_invocation_result['Status']
    return {
        'statusCode': 200,
        'body': json.dumps({"status": status, "command_id": command_id, "instance_id": instance_id}),
        'command_id': command_id,
        'instance_id': instance_id,
        'status': status
    }
